# 시작하기!

Rapunzel에 오신 것을 환영합니다, Python과 R의 현대적인 개발 환경입니다. 다음은 몇 가지 유용한 키보드 단축키입니다.

## 프로젝트 폴더와 파일 작업하기

- [`Ctrl+Shift+O`: 프로젝트 폴더 열기](opensesame://event.rapunzel_welcome_open_folders)
- [`Ctrl+O`: 프로젝트 폴더에서 파일 열기](opensesame://event.rapunzel_welcome_open_files)
- [`Ctrl+N`: 빈 문서 생성하기](opensesame://event.ide_new_file)

## 빠르게 작업하기

- [`Ctrl+Shift+P`: 명령 팔레트 활성화하기](opensesame://event.command_palette_activate)
- `Ctrl+R`: 함수나 클래스로 이동하기

## 코드 실행하기

- `F5`: 프로젝트 또는 파일 실행하기
- `F9`: 선택한 부분, 셀, 또는 현재 줄 실행하기